%
% Baccala & Sameshima. Balanced Notch Filter - zero midband transmission
% 
% 

clear; clc
N=100000;
disp('======================================================================');
disp('                         Midband Notch Model                          ')
%disp('         Baccala & Sameshima. Biol. Cybern. 84:463-474, 2001.')
%disp('           x1==>x2  x1-->x3 x1-->x4 x4-->x5 x5-->x4 x5-->x1');
disp('======================================================================');

randn('state', sum(100*clock))
% Balanced innovations input
SZ=[100 0.5 ;0.5 1];SZ=chol(SZ);
wi=randn(2,N);
wi=SZ'*wi;
x1=zeros(1,N);
x2=zeros(1,N);
%x3=zeros(1,N);
%x4=zeros(1,N);
%x5=zeros(1,N);
% Variables initialization
for t=1:3,
   x1(t)=randn(1); x2(t)=randn(1);%
   %x3(t)=randn(1);
   %x4(t)=randn(1);
   %x5(t)=randn(1);
end;

chLabels = []; % or 
%chLabels = {'x_1';'x_2';'x_3';'x_4';'x_5'};

for t=4:N,
   x1(t) = .5*x1(t-1)+ wi(1,t);
   x2(t) = -.5*x2(t-1)+x1(t-1)+x1(t-3) + wi(2,t);
end;

nDiscard=40000; % number of points discarded at beginning of series (sem efeito)
nPoints=1000;   % number of analyzed samples points

y=[x1' x2']; % data must be organized column-wise

u=y(N-nPoints+1:N,:);%size(u),pause

%==========================================================================
%             original PDCn estimation and analysis parameters
%==========================================================================

run example_analysis_parameters % Setting default paramaters 
nFreqs=1024;
% maxIP=3; 
% criterion=5;
run example_pre_processing      % Detrending and/or standardization

run example_mvar_estimation     % Estimating VAR and testing adequacy of 
                                % VAR model as well as performing GCT and ICT.

%=======Overriding some default parameters for plotting and analysis=======

flgPrinting = [2 1 1 2 2 0 0]; % overriding default setting
alpha=0.05
% alpha=0.05;         % Significance level
% gct_signif = 0.05;  % Granger causality test significance level
% igct_signif = 0.05; % Instantaneous GCT significance level

metric = 'euc';

run example_pdc_analysis

%save notch_unbalanced_pdc

%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
w_max=fs/2;
flgColor = 0;   
for kflgColor = flgColor,
   h=figure;
    set(h,'NumberTitle','off','MenuBar','none', ...
          'Name', 'Figure 7.4(a) PDC Midband Notch')
   [hxlabel hylabel] = pdc_xplot_article2(c,...
                              flgPrinting,fs,w_max,chLabels,kflgColor);
   [ax,hT]=suplabel(['Unbalanced notch: ' ...
      int2str(nPoints) ' data points.'],'t');
   set(hT,'FontSize',10); % Title font size
   pdc_xplot_title(alpha,metric);
end;



metric = 'info';

run example_pdc_analysis

%save baccala2001a_ex5_PDC

%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
w_max=fs/2;
   
for kflgColor = flgColor,
   h=figure;
    set(h,'NumberTitle','off','MenuBar','none', ...
          'Name', 'Figure 7.4(b) iPDC Midband Notch')
   [hxlabel hylabel] = pdc_xplot_article2(c,...
                              flgPrinting,fs,w_max,chLabels,kflgColor);
   [ax,hT]=suplabel(['Unbalanced notch: ' ...
      int2str(nPoints) ' data points.'],'t');
   set(hT,'FontSize',10); % Title font size
   pdc_xplot_title(alpha,metric);
end;
