%
% Baccala & Sameshima. Balanced Notch Filter - zero midband transmission
% Chapter 7, Example 7.1 
% 

clear; clc
N=100000;
disp('======================================================================');
disp('           Simple Example -- Matching Baccala et. 2006      ')
disp('         Sameshima & Baccala. Asymp PDC Properties.')
disp('           x1-->x2');
disp('======================================================================');

randn('state', sum(100*clock))
% Balanced innovations input
SZ=[1 0 ;0 1];SZ=chol(SZ);
wi=randn(2,N);
wi=SZ*wi;
x1=zeros(1,N);
x2=zeros(1,N);

% Variables initialization
for t=1:3,
   x1(t)=randn(1); x2(t)=randn(1);%
end;

chLabels = []; % or 
%chLabels = {'x_1';'x_2';'x_3';'x_4';'x_5'};

for t=4:N,
   x1(t) = .5*x1(t-1)+ wi(1,t);
   x2(t) = .5*x2(t-1)+.5*x1(t-1) + wi(2,t);
end;

nDiscard=40000; % number of points discarded at beginning of series (sem efeito)
nPoints=100;    % number of analyzed samples points

y=[x1' x2'];    % data must be organized column-wise

u=y(N-nPoints+1:N,:);%size(u),pause

%==========================================================================
%             original PDCn estimation and analysis parameters
%==========================================================================

run example_analysis_parameters % Setting default paramaters 

run example_pre_processing      % Detrending and/or standardization

run example_mvar_estimation     % Estimating VAR and testing adequacy of 
                                % VAR model as well as performing GCT and ICT.

flgPrinting = [1 1 1 2 2 0 0]; % overriding default setting

alpha=0.01;         % Significance level

% gct_signif = 0.05;  % Granger causality test significance level
% igct_signif = 0.05; % Instantaneous GCT significance level

metric = 'euc';

run example_pdc_analysis

%==========================================================================
%                        PDCn Matrix Layout Plotting
%==========================================================================
w_max=fs/2;
flgColor = 0;   
for kflgColor = flgColor,
   h=figure;
   set(h,'NumberTitle','off','MenuBar','none', ...
         'Name', 'Figure 7.1 Simple Model')
   [hxlabel hylabel] = pdc_xplot_article2(c,...
                              flgPrinting,fs,w_max,chLabels,kflgColor);
   [ax,hT]=suplabel(['Linear model Example 7.1: ' ...
      int2str(nPoints) ' data points.'],'t');
   set(hT,'FontSize',12); % Title font size
   pdc_xplot_title(alpha,metric);
end;

c